==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/el-GR/localizations.php <==
<?php

return [

    'select_language' => 'Επιλέξτε μια γλώσσα',
    'languages' => [
        'en-US'=> 'Αγγλικά, ΗΠΑ',
        'en-GB'=> 'Αγγλικά, Ηνωμένο Βασίλειο',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Αφρικάανς',
        'ar-SA'=> 'Αραβικά',
        'bg-BG'=> 'Βουλγαρικά',
        'zh-CN'=> 'Κινεζικά Απλοποιημένα',
        'zh-TW'=> 'Παραδοσιακά Κινέζικα',
        'ca-ES' => 'Καταλανικά',
        'hr-HR'=> 'Κροατικά',
        'cs-CZ'=> 'Τσέχικα',
        'da-DK'=> 'Δανέζικα',
        'nl-NL'=> 'Ολλανδικά',
        'en-ID'=> 'Αγγλικά, Ινδονησία',
        'et-EE'=> 'Εσθονικά',
        'fil-PH'=> 'Φιλιππινέζικα',
        'fi-FI'=> 'Φινλανδικά',
        'fr-FR'=> 'Γαλλικά',
        'de-DE'=> 'Γερμανικά',
        'de-if'=> 'Γερμανικά (Πληροφορικά)',
        'el-GR'=> 'Ελληνικά',
        'he-IL'=> 'Εβραϊκά',
        'hu-HU'=> 'Ουγγρικά',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Ινδονησιακά',
        'ga-IE'=> 'Ιρλανδικά',
        'it-IT'=> 'Ιταλικά',
        'ja-JP'=> 'Ιαπωνικά',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Κορεάτικα',
        'lt-LT'=>'Λιθουανικά',
        'lv-LV'=> 'Λετονικά',
        'mk-MK'=> 'Σλαβομακεδονικά',
        'ms-MY'=> 'Μαλαισιανά',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Μογγολικά',
        'no-NO'=> 'Νορβηγικά',
        'fa-IR'=> 'Περσικά',
        'pl-PL'=> 'Πολωνικά',
        'pt-PT'=> 'Πορτογαλικά',
        'pt-BR'=> 'Πορτογαλικά, Βραζιλίας',
        'ro-RO'=> 'Ρουμανικά',
        'ru-RU'=> 'Ρωσικά',
        'sr-CS' => 'Serbian (Latin)',
        'sk-SK'=> 'Σλοβακικά',
        'sl-SI'=> 'Slovenian',
        'es-ES'=> 'Ισπανικά',
        'es-CO'=> 'Ισπανικά, Κολομβία',
        'es-MX'=> 'Ισπανικά, Μεξικό',
        'es-VE'=> 'Ισπανικά, Βενεζουέλα',
        'sv-SE'=> 'Σουηδικά',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Ταϊλανδικά',
        'tr-TR'=> 'Τουρκικά',
        'uk-UA'=> 'Ουκρανικά',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Ουαλικά',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Επιλέξτε μια χώρα',
    
    'countries' => [
        'AC'=>'Νήσος Αναλήψεως',
        'AD'=>'Andorra',
        'AE'=>'Ηνωμένα Αραβικά Εμιράτα',
        'AF'=>'Αφγανιστάν',
        'AG'=>'Αντίγκουα Και Μπαρμπούντα',
        'AI'=>'Anguilla',
        'AL'=>'Αλβανία',
        'AM'=>'Αρμενία',
        'AN'=>'Ολλανδικές Αντίλλες',
        'AO'=>'Αγκόλα',
        'AQ'=>'Antarctica',
        'AR'=>'Αργεντινή',
        'AS'=>'American Samoa',
        'AT'=>'Αυστρία',
        'AU'=>'Αυστραλία',
        'AW'=>'Aruba',
        'AX'=>'A\' A €; γη',
        'AZ'=>'Αζερμπαϊτζάν',
        'BA'=>'Βοσνία Ερζεγοβίνη',
        'BB'=>'Μπαρμπάντος',
        'BE'=>'Βέλγιο',
        'BD'=>'Μπαγκλαντές',
        'BF'=>'Μπουρκίνα Φάσο',
        'BG'=>'Βουλγαρία',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Μπρουνέι Νταρουσαλάμ',
        'BO'=>'Bolivia',
        'BR'=>'Βραζιλία',
        'BS'=>'Bahamas',
        'BT'=>'Μπουτάν',
        'BV'=>'Νήσος Μπουβέ',
        'BW'=>'Botswana',
        'BY'=>'Λευκορωσία',
        'BZ'=>'Μπελίζ',
        'CA'=>'Καναδάς',
        'CC'=>'Νησιά Κόκος (Κίλινγκ)',
        'CD'=>'Κονγκό (Λαϊκή Δημοκρατία)',
        'CF'=>'Κεντροαφρικανική Δημοκρατία',
        'CG'=>'Κονγκό (Δημοκρατία)',
        'CH'=>'Ελβετία',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Νήσοι Κουκ',
        'CL'=>'Χιλή',
        'CM'=>'Καμερούν',
        'CN'=>'Λαϊκή Δημοκρατία της Κίνας',
        'CO'=>'Κολομβία',
        'CR'=>'Κόστα Ρίκα',
        'CU'=>'Cuba',
        'CV'=>'Πράσινο Ακρωτήριο',
        'CX'=>'Νήσος Των Χριστουγέννων',
        'CY'=>'Κύπρος',
        'CZ'=>'Τσεχική Δημοκρατία',
        'DE'=>'Γερμανία',
        'DJ'=>'Djibouti',
        'DK'=>'Δανία',
        'DM'=>'Ντομίνικα',
        'DO'=>'Δομινικανή Δημοκρατία',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Εσθονία',
        'EG'=>'Αίγυπτος',
        'ER'=>'Ερυθραία',
        'ES'=>'Ισπανία',
        'ET'=>'Ethiopia',
        'EU'=>'Ευρωπαϊκή Ένωση',
        'FI'=>'Φινλανδία',
        'FJ'=>'Fiji',
        'FK'=>'Νήσοι Φώκλαντ (Μαλβίνες)',
        'FM'=>'Ομόσπονδες Πολιτείες Μικρονησίας',
        'FO'=>'Νήσοι Φερόε',
        'FR'=>'Γαλλία',
        'GA'=>'Gabon',
        'GD'=>'Γρενάδα',
        'GE'=>'Γεωργία',
        'GF'=>'Γαλλική Γουιάνα',
        'GG'=>'Guernsey',
        'GH'=>'Γκάνα',
        'GI'=>'Γιβραλτάρ',
        'GL'=>'Γροιλανδία',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Ελλάδα',
        'GS'=>'Νότια Γεωργία Και Νότιες Νήσοι Σάντουιτς',
        'GT'=>'Γουατεμάλα',
        'GU'=>'Γκουάμ',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Χονγκ Κονγκ',
        'HM'=>'Χερντ Και Mc Ντόναλντ Νήσοι',
        'HN'=>'Honduras',
        'HR'=>'Κροατία (τοπικό όνομα: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ουγγαρία',
        'ID'=>'Ινδονησία',
        'IE'=>'Ιρλανδία',
        'IL'=>'Israel',
        'IM'=>'Νήσος του Μαν',
        'IN'=>'Ινδία',
        'IO'=>'Βρετανικό Έδαφος Ινδικού Ωκεανού',
        'IQ'=>'Ιράκ',
        'IR'=>'Ιράν, Ισλαμική Δημοκρατία',
        'IS'=>'Ισλανδία',
        'IT'=>'Ιταλία',
        'JE'=>'Τζέρσεϊ',
        'JM'=>'Jamaica',
        'JO'=>'Ιορδανία',
        'JP'=>'Ιαπωνία',
        'KE'=>'Κένυα',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Καμπότζη',
        'KI'=>'Kiribati',
        'KM'=>'Κομόρες',
        'KN'=>'Άγιος Χριστόφορος Και Νέβις',
        'KR'=>'Κορέα, Δημοκρατία Της',
        'KW'=>'Kuwait',
        'KY'=>'Νήσοι Κέιμαν',
        'KZ'=>'Καζακστάν',
        'LA'=>'Λαϊκή Δημοκρατία Του Λάος',
        'LB'=>'Lebanon',
        'LC'=>'Αγία Λουκία',
        'LI'=>'Liechtenstein',
        'LK'=>'Σρι Λάνκα',
        'LR'=>'Λιβερία',
        'LS'=>'Lesotho',
        'LT'=>'Λιθουανία',
        'LU'=>'Luxembourg',
        'LV'=>'Λετονία',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Μαρόκο',
        'MC'=>'Μονακό',
        'MD'=>'Μολδαβία, Δημοκρατία Της',
        'ME'=>'Μαυροβούνιο',
        'MG'=>'Madagascar',
        'MH'=>'Νήσοι Μάρσαλ',
        'MK'=>'Μακεδονία, Πρώην Γιουγκοσλαβική Δημοκρατία Της',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Μακάο',
        'MP'=>'Νήσοι Βόρειες Μαριάνες',
        'MQ'=>'Μαρτινίκα',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Μαλδίβες',
        'MW'=>'Malawi',
        'MX'=>'Μεξικό',
        'MY'=>'Μαλαισία',
        'MZ'=>'Μοζαμβίκη',
        'NA'=>'Namibia',
        'NC'=>'Νέα Καληδονία',
        'NE'=>'Niger',
        'NF'=>'Νήσος Νόρφολκ',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Ολλανδία',
        'NO'=>'Νορβηγία',
        'NP'=>'Νεπάλ',
        'NR'=>'Nauru',
        'NU'=>'Νιούε',
        'NZ'=>'Νέα Ζηλανδία',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Περού',
        'PF'=>'Γαλλική Πολυνησία',
        'PG'=>'Papua New Guinea',
        'PH'=>'Φιλιππίνες, Δημοκρατία της',
        'PK'=>'Πακιστάν',
        'PL'=>'Πολωνία',
        'PM'=>'Σαιν Πιερ Και Μικελόν',
        'PN'=>'Πίτκαιρν',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Πορτογαλία',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Ρεουνιόν',
        'RO'=>'Ρουμανία',
        'RS'=>'Σερβία',
        'RU'=>'Ρωσική Ομοσπονδία',
        'RW'=>'Rwanda',
        'SA'=>'Σαουδική Αραβία',
        'UK'=>'Σκωτία',
        'SB'=>'Νήσοι Σολομώντος',
        'SC'=>'Seychelles',
        'SS'=>'Νότιο Σουδάν',
        'SD'=>'Sudan',
        'SE'=>'Σουηδία',
        'SG'=>'Σιγκαπούρη',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Νήσοι Σβάλμπαρντ Και Γιαν Μαγιέν',
        'SK'=>'Σλοβακία (Σλοβακική Δημοκρατία)',
        'SL'=>'Σιέρα Λεόνε',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Σάο Τομέ Και Πρίνσιπε',
        'SU'=>'Σοβιετική Ένωση',
        'SV'=>'El Salvador',
        'SY'=>'Αραβική Δημοκρατία Της Συρίας',
        'SZ'=>'Swaziland',
        'TC'=>'Νήσοι Τερκς Και Κάικος',
        'TD'=>'Τσαντ',
        'TF'=>'Γαλλικά Νότια Εδάφη',
        'TG'=>'Τόγκο',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Ανατολικό Τιμόρ',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'Ανατολικό Τιμόρ (παλιός κωδικός)',
        'TR'=>'Τουρκία',
        'TT'=>'Τρινιντάντ Και Τομπάγκο',
        'TV'=>'Tuvalu',
        'TW'=>'Ταϊβάν',
        'TZ'=>'Τανζανία, Ηνωμένο Βασίλειο',
        'UA'=>'Ουκρανία',
        'UG'=>'Uganda',
        'UK'=>'Ηνωμένο Βασίλειο',
        'US'=>'Ηνωμένες Πολιτείες',
        'UM'=>'Μικρά Απομονωμένα Νησιά Των Ηνωμένων Πολιτειών',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Κράτος Της Πόλης Του Βατικανού',
        'VC'=>'Άγιος Βικέντιος Και Γρεναδίνες',
        'VE'=>'Βενεζουέλα',
        'VG'=>'Παρθένες Νήσοι (Βρετανικές)',
        'VI'=>'Παρθένες Νήσοι (Η.Π.Α.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'WF'=>'Νήσοι Ουώλλις Και Φουτούνα',
        'WS'=>'Samoa',
        'YE'=>'Υεμένη',
        'YT'=>'Μαγιότ',
        'ZA'=>'Νότια Αφρική',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/el-GR/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'Αγγλικά, ΗΠΑ',
        'en-GB'=> 'Αγγλικά, Ηνωμένο Βασίλειο',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Αφρικάανς',
        'ar-SA'=> 'Αραβικά',
        'bg-BG'=> 'Βουλγαρικά',
        'zh-CN'=> 'Κινεζικά Απλοποιημένα',
        'zh-TW'=> 'Παραδοσιακά Κινέζικα',
        'ca-ES' => 'Καταλανικά',
        'hr-HR'=> 'Κροατικά',
        'cs-CZ'=> 'Τσέχικα',
        'da-DK'=> 'Δανέζικα',
        'nl-NL'=> 'Ολλανδικά',
        'en-ID'=> 'Αγγλικά, Ινδονησία',
        'et-EE'=> 'Εσθονικά',
        'fil-PH'=> 'Φιλιππινέζικα',
        'fi-FI'=> 'Φινλανδικά',
        'fr-FR'=> 'Γαλλικά',
        'de-DE'=> 'Γερμανικά',
        'de-if'=> 'Γερμανικά (Πληροφορικά)',
        'el-GR'=> 'Ελληνικά',
        'he-IL'=> 'Εβραϊκά',
        'hu-HU'=> 'Ουγγρικά',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Ινδονησιακά',
        'ga-IE'=> 'Ιρλανδικά',
        'it-IT'=> 'Ιταλικά',
        'ja-JP'=> 'Ιαπωνικά',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Κορεάτικα',
        'lt-LT'=>'Λιθουανικά',
        'lv-LV'=> 'Λετονικά',
        'mk-MK'=> 'Σλαβομακεδονικά',
        'ms-MY'=> 'Μαλαισιανά',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Μογγολικά',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Περσικά',
        'pl-PL'=> 'Πολωνικά',
        'pt-PT'=> 'Πορτογαλικά',
        'pt-BR'=> 'Πορτογαλικά, Βραζιλίας',
        'ro-RO'=> 'Ρουμανικά',
        'ru-RU'=> 'Ρωσικά',
        'sr-CS' => 'Serbian (Latin)',
        'sk-SK'=> 'Σλοβακικά',
        'sl-SI'=> 'Slovenian',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Ισπανικά',
        'es-CO'=> 'Ισπανικά, Κολομβία',
        'es-MX'=> 'Ισπανικά, Μεξικό',
        'es-VE'=> 'Ισπανικά, Βενεζουέλα',
        'sv-SE'=> 'Σουηδικά',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Ταϊλανδικά',
        'tr-TR'=> 'Τουρκικά',
        'uk-UA'=> 'Ουκρανικά',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Ουαλικά',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Νήσος Αναλήψεως',
        'AD'=>'Andorra',
        'AE'=>'Ηνωμένα Αραβικά Εμιράτα',
        'AF'=>'Αφγανιστάν',
        'AG'=>'Αντίγκουα Και Μπαρμπούντα',
        'AI'=>'Anguilla',
        'AL'=>'Αλβανία',
        'AM'=>'Αρμενία',
        'AN'=>'Ολλανδικές Αντίλλες',
        'AO'=>'Αγκόλα',
        'AQ'=>'Antarctica',
        'AR'=>'Αργεντινή',
        'AS'=>'American Samoa',
        'AT'=>'Αυστρία',
        'AU'=>'Αυστραλία',
        'AW'=>'Aruba',
        'AX'=>'A\' A €; γη',
        'AZ'=>'Αζερμπαϊτζάν',
        'BA'=>'Βοσνία Ερζεγοβίνη',
        'BB'=>'Μπαρμπάντος',
        'BE'=>'Βέλγιο',
        'BD'=>'Μπαγκλαντές',
        'BF'=>'Μπουρκίνα Φάσο',
        'BG'=>'Βουλγαρία',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Μπρουνέι Νταρουσαλάμ',
        'BO'=>'Bolivia',
        'BR'=>'Βραζιλία',
        'BS'=>'Bahamas',
        'BT'=>'Μπουτάν',
        'BV'=>'Νήσος Μπουβέ',
        'BW'=>'Botswana',
        'BY'=>'Λευκορωσία',
        'BZ'=>'Μπελίζ',
        'CA'=>'Καναδάς',
        'CC'=>'Νησιά Κόκος (Κίλινγκ)',
        'CD'=>'Κονγκό (Λαϊκή Δημοκρατία)',
        'CF'=>'Κεντροαφρικανική Δημοκρατία',
        'CG'=>'Κονγκό (Δημοκρατία)',
        'CH'=>'Ελβετία',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Νήσοι Κουκ',
        'CL'=>'Χιλή',
        'CM'=>'Καμερούν',
        'CN'=>'Λαϊκή Δημοκρατία της Κίνας',
        'CO'=>'Κολομβία',
        'CR'=>'Κόστα Ρίκα',
        'CU'=>'Cuba',
        'CV'=>'Πράσινο Ακρωτήριο',
        'CX'=>'Νήσος Των Χριστουγέννων',
        'CY'=>'Κύπρος',
        'CZ'=>'Τσεχική Δημοκρατία',
        'DE'=>'Γερμανία',
        'DJ'=>'Djibouti',
        'DK'=>'Δανία',
        'DM'=>'Ντομίνικα',
        'DO'=>'Δομινικανή Δημοκρατία',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Εσθονία',
        'EG'=>'Αίγυπτος',
        'GB-ENG'=>'England',
        'ER'=>'Ερυθραία',
        'ES'=>'Ισπανία',
        'ET'=>'Ethiopia',
        'EU'=>'Ευρωπαϊκή Ένωση',
        'FI'=>'Φινλανδία',
        'FJ'=>'Fiji',
        'FK'=>'Νήσοι Φώκλαντ (Μαλβίνες)',
        'FM'=>'Ομόσπονδες Πολιτείες Μικρονησίας',
        'FO'=>'Νήσοι Φερόε',
        'FR'=>'Γαλλία',
        'GA'=>'Gabon',
        'GD'=>'Γρενάδα',
        'GE'=>'Γεωργία',
        'GF'=>'Γαλλική Γουιάνα',
        'GG'=>'Guernsey',
        'GH'=>'Γκάνα',
        'GI'=>'Γιβραλτάρ',
        'GL'=>'Γροιλανδία',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Ελλάδα',
        'GS'=>'Νότια Γεωργία Και Νότιες Νήσοι Σάντουιτς',
        'GT'=>'Γουατεμάλα',
        'GU'=>'Γκουάμ',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Χονγκ Κονγκ',
        'HM'=>'Χερντ Και Mc Ντόναλντ Νήσοι',
        'HN'=>'Honduras',
        'HR'=>'Κροατία (τοπικό όνομα: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ουγγαρία',
        'ID'=>'Ινδονησία',
        'IE'=>'Ιρλανδία',
        'IL'=>'Israel',
        'IM'=>'Νήσος του Μαν',
        'IN'=>'Ινδία',
        'IO'=>'Βρετανικό Έδαφος Ινδικού Ωκεανού',
        'IQ'=>'Ιράκ',
        'IR'=>'Ιράν, Ισλαμική Δημοκρατία',
        'IS'=>'Ισλανδία',
        'IT'=>'Ιταλία',
        'JE'=>'Τζέρσεϊ',
        'JM'=>'Jamaica',
        'JO'=>'Ιορδανία',
        'JP'=>'Ιαπωνία',
        'KE'=>'Κένυα',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Καμπότζη',
        'KI'=>'Kiribati',
        'KM'=>'Κομόρες',
        'KN'=>'Άγιος Χριστόφορος Και Νέβις',
        'KR'=>'Κορέα, Δημοκρατία Της',
        'KW'=>'Kuwait',
        'KY'=>'Νήσοι Κέιμαν',
        'KZ'=>'Καζακστάν',
        'LA'=>'Λαϊκή Δημοκρατία Του Λάος',
        'LB'=>'Lebanon',
        'LC'=>'Αγία Λουκία',
        'LI'=>'Liechtenstein',
        'LK'=>'Σρι Λάνκα',
        'LR'=>'Λιβερία',
        'LS'=>'Lesotho',
        'LT'=>'Λιθουανία',
        'LU'=>'Luxembourg',
        'LV'=>'Λετονία',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Μαρόκο',
        'MC'=>'Μονακό',
        'MD'=>'Μολδαβία, Δημοκρατία Της',
        'ME'=>'Μαυροβούνιο',
        'MG'=>'Madagascar',
        'MH'=>'Νήσοι Μάρσαλ',
        'MK'=>'Μακεδονία, Πρώην Γιουγκοσλαβική Δημοκρατία Της',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Μακάο',
        'MP'=>'Νήσοι Βόρειες Μαριάνες',
        'MQ'=>'Μαρτινίκα',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Μαλδίβες',
        'MW'=>'Malawi',
        'MX'=>'Μεξικό',
        'MY'=>'Μαλαισία',
        'MZ'=>'Μοζαμβίκη',
        'NA'=>'Namibia',
        'NC'=>'Νέα Καληδονία',
        'NE'=>'Niger',
        'NF'=>'Νήσος Νόρφολκ',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Ολλανδία',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Νορβηγία',
        'NP'=>'Νεπάλ',
        'NR'=>'Nauru',
        'NU'=>'Νιούε',
        'NZ'=>'Νέα Ζηλανδία',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Περού',
        'PF'=>'Γαλλική Πολυνησία',
        'PG'=>'Papua New Guinea',
        'PH'=>'Φιλιππίνες, Δημοκρατία της',
        'PK'=>'Πακιστάν',
        'PL'=>'Πολωνία',
        'PM'=>'Σαιν Πιερ Και Μικελόν',
        'PN'=>'Πίτκαιρν',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Πορτογαλία',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Ρεουνιόν',
        'RO'=>'Ρουμανία',
        'RS'=>'Σερβία',
        'RU'=>'Ρωσική Ομοσπονδία',
        'RW'=>'Rwanda',
        'SA'=>'Σαουδική Αραβία',
        'GB-SCT'=>'Σκωτία',
        'SB'=>'Νήσοι Σολομώντος',
        'SC'=>'Seychelles',
        'SS'=>'Νότιο Σουδάν',
        'SD'=>'Sudan',
        'SE'=>'Σουηδία',
        'SG'=>'Σιγκαπούρη',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Νήσοι Σβάλμπαρντ Και Γιαν Μαγιέν',
        'SK'=>'Σλοβακία (Σλοβακική Δημοκρατία)',
        'SL'=>'Σιέρα Λεόνε',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Σάο Τομέ Και Πρίνσιπε',
        'SU'=>'Σοβιετική Ένωση',
        'SV'=>'El Salvador',
        'SY'=>'Αραβική Δημοκρατία Της Συρίας',
        'SZ'=>'Swaziland',
        'TC'=>'Νήσοι Τερκς Και Κάικος',
        'TD'=>'Τσαντ',
        'TF'=>'Γαλλικά Νότια Εδάφη',
        'TG'=>'Τόγκο',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'Ανατολικό Τιμόρ',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'Ανατολικό Τιμόρ (παλιός κωδικός)',
        'TR'=>'Τουρκία',
        'TT'=>'Τρινιντάντ Και Τομπάγκο',
        'TV'=>'Tuvalu',
        'TW'=>'Ταϊβάν',
        'TZ'=>'Τανζανία, Ηνωμένο Βασίλειο',
        'UA'=>'Ουκρανία',
        'UG'=>'Uganda',
        'UK'=>'Ηνωμένο Βασίλειο',
        'US'=>'Ηνωμένες Πολιτείες',
        'UM'=>'Μικρά Απομονωμένα Νησιά Των Ηνωμένων Πολιτειών',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Κράτος Της Πόλης Του Βατικανού',
        'VC'=>'Άγιος Βικέντιος Και Γρεναδίνες',
        'VE'=>'Βενεζουέλα',
        'VG'=>'Παρθένες Νήσοι (Βρετανικές)',
        'VI'=>'Παρθένες Νήσοι (Η.Π.Α.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Νήσοι Ουώλλις Και Φουτούνα',
        'WS'=>'Samoa',
        'YE'=>'Υεμένη',
        'YT'=>'Μαγιότ',
        'ZA'=>'Νότια Αφρική',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
